@@ -1,24 +1,21 @@
 package App::CharmKit::Command::clone;
-$App::CharmKit::Command::clone::VERSION = '0.017';
+$App::CharmKit::Command::clone::VERSION = '0.18';
 # ABSTRACT: Clone charm from github
 
 
 use strict;
 use warnings;
+use Path::Tiny;
 use App::CharmKit -command;
-use parent 'App::CharmKit::Role::GitHub';
+use parent 'App::CharmKit::Role::Git';
 
 sub opt_spec {
-    return (
-        [   "output|o=s",
-            "Destination directory to place cloned charm"
-        ]
-    );
+    return (["output|o=s", "Destination directory to place cloned charm"],);
 }
 
 sub usage_desc {
     my $self = shift;
-    my $eg   = "charmkit get battlemidget/charm-plone -o plone";
+    my $eg   = "charmkit clone battlemidget/charm-plone -o plone";
     "$eg\n\n%c clone [-o]";
 }
 
@@ -33,7 +30,7 @@ sub validate_args {
 sub execute {
     my ($self, $opt, $args) = @_;
     if ($opt->{output}) {
-        $self->clone($args->[0], $opt->{output});
+        $self->clone($args->[0], path($opt->{output}));
     }
     else {
         $self->clone($args->[0]);
@@ -54,15 +51,15 @@ App::CharmKit::Command::clone - Clone charm from github
 
 =head1 VERSION
 
-version 0.017
+version 0.18
 
 =head1 SYNOPSIS
 
-  $ charmkit clone battlemidget/charm-plone -o plone
+  $ charmkit clone battlemidget/charm-plone -o ~/charms/trusty/plone
 
 =head1 DESCRIPTION
 
-Clones a charm from GitHub
+Clones a charm from a git endpoint, supports GitHub with <username>/<repo>.
 
 =head1 AUTHOR
 
