@@ -1,35 +1,49 @@
 package App::CharmKit::Command::deploy;
-$App::CharmKit::Command::deploy::VERSION = '0.017';
+$App::CharmKit::Command::deploy::VERSION = '0.18';
 # ABSTRACT: Deploy charm
 
 
 use strict;
 use warnings;
+use Path::Tiny;
+use App::CharmKit::Sys "execute" => { -as => "run" };
 use App::CharmKit -command;
 
 sub opt_spec {
     return (
         [   "charmdir|c=s",
             "Location of toplevel charm directory, used in local charm deploys"
-        ]
+        ],
+        ["series|s=s", "Series of charm, defaults to trusty"]
     );
 }
 
 sub usage_desc {
-    "charmkit deploy git\@github.com:battlemidget/charm.git -c ~/charms";
+    "charmkit deploy <charmname> -c ~/charms";
 }
 
 sub validate_args {
     my ($self, $opt, $args) = @_;
-    $self->usage_error("Needs a charm path")
+    $self->usage_error("Needs a charm name")
       unless $args->[0];
     $self->usage_error("No toplevel charm directory found")
       unless $opt->{charmdir};
+    $self->usage_error("Charm directory does not exist")
+      unless path($opt->{charmdir})->exists;
 }
 
 sub execute {
     my ($self, $opt, $args) = @_;
-    print("poof.\n");
+    my $series = $opt->{series} || "trusty";
+    my $cmd = sprintf("juju deploy --repository=%s local:%s/%s",
+        $opt->{charmdir}, $series, $args->[0]);
+    my $out = run([$cmd]);
+    if ($out->{error}) {
+        printf("Deployed failed: %s", $out->{stderr});
+    }
+    else {
+        printf("Deployed: %s", $out->{stdout});
+    }
 }
 
 1;
@@ -46,11 +60,11 @@ App::CharmKit::Command::deploy - Deploy charm
 
 =head1 VERSION
 
-version 0.017
+version 0.18
 
 =head1 SYNOPSIS
 
-  $ charmkit deploy (git|http|file)://charm-path(.git|.tar.gz)
+  $ charmkit deploy <charmname> -c ~/charms
 
 =head1 DESCRIPTION
 
